@@ -2,113 +2,50 @@
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
-import os
+
 import fnmatch
 import math
-from collections import defaultdict
-import subprocess
-import warnings
+import os
 import shutil
+import subprocess
+import tarfile
+import warnings
+from collections import defaultdict
 import yaml
-import numpy as np
-import ROOT as r
+
+# try to use LibYAML bindings if possible
+try:
+    from yaml import CLoader as Loader, CDumper as Dumper
+except ImportError:
+    from yaml import Loader, Dumper
+from yaml.representer import SafeRepresenter
+
+from hepdata_lib import helpers
+from hepdata_lib.root_utils import RootFileReader
+
+MAPPING_TAG = yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG
 
 
-# Register defalut dict so that yaml knows it is a dictionary type
-yaml.add_representer(defaultdict, yaml.representer.Representer.represent_dict)
+def dict_representer(dumper, data):
+    """represent dict."""
+    return dumper.represent_dict(data.items())
 
 
+def dict_constructor(loader, node):
+    """construct dict."""
+    return defaultdict(loader.construct_pairs(node))
+
+
+Dumper.add_representer(defaultdict, dict_representer)
+Loader.add_constructor(MAPPING_TAG, dict_constructor)
+
+Dumper.add_representer(str,
+                       SafeRepresenter.represent_str)
+
 # Display deprecation warnings
 warnings.filterwarnings("always", category=DeprecationWarning, module="hepdata_lib")
 
-def execute_command(command):
-    """
-    Execute shell command using subprocess.
-    If executable does not exist, return False.
-    For other errors raise RuntimeError.
-    Else return True on success.
-
-    :param command: Command to execute.
-    :type command: string
-    """
-    proc = subprocess.Popen(
-        command,
-        stdin=subprocess.PIPE,
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
-        shell=True,
-        universal_newlines=True)
-    exit_code = proc.wait()
-    if exit_code == 127:
-        print("Command does not exist:", command)
-        return False
-    if exit_code != 0:
-        result = ""
-        for line in proc.stderr:
-            result = result + line
-        raise RuntimeError(result)
-    return True
-
-
-def find_all_matching(path, pattern):
-    """Utility function that works like 'find' in bash."""
-    if not os.path.exists(path):
-        raise RuntimeError("Invalid path '{0}'".format(path))
-    result = []
-    for root, _, files in os.walk(path):
-        for thisfile in files:
-            if fnmatch.fnmatch(thisfile, pattern):
-                result.append(os.path.join(root, thisfile))
-    return result
-
-
-def relative_round(value, relative_digits):
-    """Rounds to a given relative precision"""
-    if value == 0:
-        return 0
-    if isinstance(value, str) or np.isnan(value):
-        return value
-
-    value_precision = math.ceil(math.log10(abs(value)))
-
-    absolute_digits = -value_precision + relative_digits
-    if absolute_digits < 0:
-        absolute_digits = 0
-
-    return round(value, int(absolute_digits))
-
-def check_file_existence(path_to_file):
-    """
-    Check that the given file path exists.
-    If not, raise RuntimeError.
-
-    :param path_to_file: File path to check.
-    :type path_to_file: string
-    """
-    if not os.path.exists(path_to_file):
-        raise RuntimeError("Cannot find file: " + path_to_file)
-
-def check_file_size(path_to_file, upper_limit=None, lower_limit=None):
-    """
-    Check that the file size is between the upper and lower limits.
-    If not, raise RuntimeError.
-
-    :param path_to_file: File path to check.
-    :type path_to_file: string
-
-    :param upper_limit: Upper size limit in MB.
-    :type upper_limit: float
-
-    :param lower_limit: Lower size limit in MB.
-    :type lower_limit: float
-    """
-    size = 1e-6 * os.path.getsize(path_to_file)
-    if upper_limit and size > upper_limit:
-        raise RuntimeError("File too big: '{0}'. Maximum allowed value is {1} \
-                            MB.".format(path_to_file, upper_limit))
-    if lower_limit and size < lower_limit:
-        raise RuntimeError("File too small: '{0}'. Minimal allowed value is {1} \
-                            MB.".format(path_to_file, lower_limit))
+__version__ = "0.3.2"
 
 class Variable(object):
     """A Variable is a wrapper for a list of values + some meta data."""
@@ -116,7 +53,8 @@ class Variable(object):
     # pylint: disable=too-many-instance-attributes
     # Eight is reasonable in this case.
 
-    def __init__(self, name, is_independent=True, is_binned=True, units=""):
+    def __init__(self, name, is_independent=True, is_binned=True, units="", values=None):
+        # pylint: disable=too-many-arguments
         self.name = name
         self.is_independent = is_independent
         self.is_binned = is_binned
@@ -124,7 +62,7 @@ class Variable(object):
         self.units = units
         # needed to make pylint happy, see https://github.com/PyCQA/pylint/issues/409
         self._values = None
-        self.values = []
+        self.values = values if values else []
         self.uncertainties = []
         self.digits = 5
 
@@ -137,9 +75,23 @@ class Variable(object):
     def values(self, value_list):
         """Value Setter."""
         if self.is_binned:
+            # Check that the input is well-formed
+            try:
+                assert all([len(x) == 2 for x in value_list])
+            except (AssertionError, TypeError, ValueError):
+                raise ValueError("For binned Variables, values should be tuples of length two: \
+                                 (lower bin edge, upper bin edge)."
+                                )
+
+            # All good
             self._values = [(float(x[0]), float(x[1])) for x in value_list]
         else:
-            self._values = [x if isinstance(x, str) else float(x) for x in value_list]
+            # Check that the input is well-formed
+            try:
+                parsed_values = [x if isinstance(x, str) else float(x) for x in value_list]
+            except (TypeError, ValueError):
+                raise ValueError("Malformed input for unbinned variable: ", value_list)
+            self._values = parsed_values
 
     def scale_values(self, factor):
         """Multiply each value by constant factor. Also applies to uncertainties."""
@@ -154,6 +106,8 @@ class Variable(object):
 
     def add_qualifier(self, name, value, units=""):
         """Add a qualifier."""
+        if self.is_independent:
+            raise RuntimeError("Qualifiers are not allowed for independent variables.")
         qualifier = {}
         qualifier["name"] = name
         qualifier["value"] = value  # if type(value) == str else float(value)
@@ -177,10 +131,10 @@ class Variable(object):
 
         lenvar = len(self.values)
         lenunc = len(uncertainty.values)
-        if lenvar and (lenvar is not lenunc):
+        if lenvar and (lenvar != lenunc):
             raise ValueError("Length of uncertainty list ({0})" \
-            "is not the same as length of Variable" \
-            "values list ({1})!.".format(lenunc, lenvar))
+                             "is not the same as length of Variable" \
+                             "values list ({1})!.".format(lenunc, lenvar))
         self.uncertainties.append(uncertainty)
 
     def make_dict(self):
@@ -198,7 +152,9 @@ class Variable(object):
         Except for debugging purposes, no user should have to call this function.
         """
         tmp = {}
-        tmp["header"] = {"name": self.name, "units": self.units}
+        tmp["header"] = {"name": self.name}
+        if self.units:
+            tmp["header"]["units"] = self.units
 
         if self.qualifiers:
             tmp["qualifiers"] = self.qualifiers
@@ -209,29 +165,29 @@ class Variable(object):
             valuedict = defaultdict(list)
 
             if self.is_binned:
-                valuedict["low"] = relative_round(self._values[i][0],
-                                                  self.digits)
-                valuedict["high"] = relative_round(self._values[i][1],
-                                                   self.digits)
+                valuedict["low"] = helpers.relative_round(self._values[i][0],
+                                                          self.digits)
+                valuedict["high"] = helpers.relative_round(self._values[i][1],
+                                                           self.digits)
             else:
-                valuedict["value"] = relative_round(self._values[i],
-                                                    self.digits)
+                valuedict["value"] = helpers.relative_round(self._values[i],
+                                                            self.digits)
 
             for unc in self.uncertainties:
                 if unc.is_symmetric:
                     valuedict['errors'].append({
                         "symerror":
-                        relative_round(unc.values[i], self.digits),
+                            helpers.relative_round(unc.values[i], self.digits),
                         "label":
-                        unc.label
+                            unc.label
                     })
                 else:
                     valuedict['errors'].append({
                         "asymerror": {
                             "minus":
-                            relative_round(unc.values[i][0], self.digits),
+                                helpers.relative_round(unc.values[i][0], self.digits),
                             "plus":
-                            relative_round(unc.values[i][1], self.digits)
+                                helpers.relative_round(unc.values[i][1], self.digits)
                         },
                         "label": unc.label
                     })
@@ -247,7 +203,10 @@ class Table(object):
     the location within the paper, etc.
     """
 
+    # pylint: disable=too-many-instance-attributes
+
     def __init__(self, name):
+        self._name = None
         self.name = name
         self.variables = []
         self.description = "Example description"
@@ -256,6 +215,18 @@ class Table(object):
         self.additional_resources = []
         self.image_files = set([])
 
+    @property
+    def name(self):
+        """Name getter."""
+        return self._name
+
+    @name.setter
+    def name(self, name):
+        """Name setter."""
+        if len(name) > 64:
+            raise ValueError("Table name must not be longer than 64 characters.")
+        self._name = name
+
     def add_image(self, file_path, outdir=None):
         """
         Add an image file to the table.
@@ -276,12 +247,13 @@ class Table(object):
                   """
             warnings.warn(msg, DeprecationWarning)
 
+        if not isinstance(file_path, str):
+            raise TypeError("Expected string argument, instead got: '{}'.".format(type(file_path)))
         if os.path.exists(file_path):
             self.image_files.add(file_path)
         else:
             raise RuntimeError("Cannot find image file: {0}".format(file_path))
 
-
     def write_output(self, outdir):
         """
         Write the table files into the output directory.
@@ -301,6 +273,9 @@ class Table(object):
                        Will be created if it doesn't exist.
         :type outdir: string
         """
+        if not isinstance(outdir, str):
+            raise TypeError("Expected string argument, instead got: '{}'.".format(type(outdir)))
+
         for image_file in self.image_files:
             if not os.path.isfile(image_file):
                 raise RuntimeError("File %s does not exist!" % image_file)
@@ -310,16 +285,16 @@ class Table(object):
                 os.path.splitext(image_file)[0].rsplit("/", 1)[1])
             thumb_out_image_file = "thumb_" + out_image_file
             # first convert to png, then create thumbnail
-            command = "convert -flatten -fuzz 1% -trim +repage {} {}/{}".format(
+            command = "convert -flatten -density 300 -fuzz 1% -trim +repage {} {}/{}".format(
                 image_file, outdir, out_image_file)
-            command_ok = execute_command(command)
+            command_ok = helpers.execute_command(command)
             if not command_ok:
                 print("ImageMagick does not seem to be installed \
                        or is not in the path - not adding any images.")
                 break
-            command = "convert -thumbnail 240x179 {}/{} {}/{}".format(
-                outdir, out_image_file, outdir, thumb_out_image_file)
-            execute_command(command)
+            command = "convert -thumbnail 240x179 {outdir}/{image} {outdir}/{thumb}".format(
+                outdir=outdir, image=out_image_file, thumb=thumb_out_image_file)
+            helpers.execute_command(command)
             image = {}
             image["description"] = "Image file"
             image["location"] = out_image_file
@@ -368,7 +343,6 @@ class Table(object):
         # Add entry to central submission file
         submission_path = os.path.join(outdir, 'submission.yaml')
         with open(submission_path, 'a+') as submissionfile:
-
             submission = {}
             submission["name"] = self.name
             submission["description"] = self.description
@@ -388,6 +362,7 @@ class Table(object):
                 explicit_start=True)
         return os.path.basename(outfile_path)
 
+
 class Submission(object):
     """
     Top-level object of a HEPData submission.
@@ -467,8 +442,8 @@ class Submission(object):
         resource = {}
         resource["description"] = description
         if copy_file:
-            check_file_existence(location)
-            check_file_size(location, upper_limit=100)
+            helpers.check_file_existence(location)
+            helpers.check_file_size(location, upper_limit=100)
             resource["location"] = os.path.basename(location)
         else:
             resource["location"] = location
@@ -506,8 +481,8 @@ class Submission(object):
         :type outdir: string
         """
         for ifile in self.files_to_copy:
-            check_file_existence(ifile)
-            check_file_size(ifile, upper_limit=100)
+            helpers.check_file_existence(ifile)
+            helpers.check_file_size(ifile, upper_limit=100)
             shutil.copy2(ifile, outdir)
 
     def create_files(self, outdir="."):
@@ -545,11 +520,10 @@ class Submission(object):
         self.copy_files(outdir)
 
         # Put everything into a tarfile
-        import tarfile
         tar = tarfile.open("submission.tar.gz", "w:gz")
-        for yaml_file in find_all_matching(outdir, "*.yaml"):
+        for yaml_file in helpers.find_all_matching(outdir, "*.yaml"):
             tar.add(yaml_file)
-        for png_file in find_all_matching(outdir, "*.png"):
+        for png_file in helpers.find_all_matching(outdir, "*.png"):
             tar.add(png_file)
         for additional in self.files_to_copy:
             tar.add(os.path.join(outdir, os.path.basename(additional)))
@@ -593,27 +567,10 @@ class Uncertainty(object):
 
         """
         if self.is_symmetric:
-            try:
-                assert all([x >= 0 for x in values])
-            except AssertionError:
-                raise ValueError(
-                    "Uncertainty::set_values: Wrong signs detected!\
-                     For symmetric uncertainty, all uncertainty values should be >=0."
-                )
             self._values = values
         else:
-            try:
-                assert all([x[1] >= 0 for x in values])
-                assert all([x[0] <= 0 for x in values])
-            except AssertionError:
-                raise ValueError(
-                    "Uncertainty::set_values: Wrong signs detected!\
-                    For asymmetric uncertainty, first element of uncertainty tuple\
-                    should be <=0, second >=0."
-                )
             self._values = [(float(x[0]), float(x[1])) for x in values]
 
-
     def set_values_from_intervals(self, intervals, nominal):
         """
         Set values relative to set of nominal valuesself.
@@ -641,316 +598,3 @@ class Uncertainty(object):
         else:
             self.values = [(factor * x[0], factor * x[1])
                            for x in self.values]
-
-
-class RootFileReader(object):
-    """Easily extract information from ROOT histograms, graphs, etc"""
-
-    def __init__(self, tfile):
-        self._tfile = None
-        self.tfile = tfile
-
-    def __del__(self):
-        if self._tfile:
-            self._tfile.Close()
-
-    @property
-    def tfile(self):
-        """The TFile this reader reads from."""
-        return self._tfile
-
-    @tfile.setter
-    def tfile(self, tfile):
-        """
-        Define the TFile to read from.
-
-        :param tfile: ROOT file to read from.
-        Can either be an already open TFile or a path to the file on disk.
-        :type tfile: TFile or str
-        """
-        if isinstance(tfile, str):
-            if os.path.exists(tfile) and tfile.endswith(".root"):
-                self._tfile = r.TFile(tfile)
-            else:
-                raise IOError("RootReader: File does not exist: " + tfile)
-        elif isinstance(tfile, r.TFile):
-            self._tfile = tfile
-        else:
-            raise ValueError(
-                "RootReader: Encountered unkonown type of variable passed as tfile argument: "
-                + str(type(tfile)))
-
-        if not self._tfile:
-            raise IOError("RootReader: File not opened properly.")
-
-    def retrieve_object(self, path_to_object):
-        """
-        Generalized function to retrieve a TObject from a file.
-
-        There are two use cases:
-        1)  The object is saved under the exact path given.
-        In this case, the function behaves identically to TFile.Get.
-        2)  The object is saved as a primitive in a TCanvas.
-        In this case, the path has to be formatted as
-        PATH_TO_CANVAS/NAME_OF_PRIMITIVE
-
-
-        :param path_to_object: Absolute path in current TFile.
-        :type path_to_object: str.
-        :returns: TObject -- The object corresponding to the given path.
-        """
-        obj = self.tfile.Get(path_to_object)
-
-        # If the Get operation was successful, just return
-        # Otherwise, try canvas approach
-        if obj:
-            return obj
-        else:
-            parts = path_to_object.split("/")
-            path_to_canvas = "/".join(parts[0:-1])
-            name = parts[-1]
-
-            try:
-                canv = self.tfile.Get(path_to_canvas)
-                assert canv
-                for entry in list(canv.GetListOfPrimitives()):
-                    if entry.GetName() == name:
-                        return entry
-
-                # Didn't find anything. Print available primitives to help user debug.
-                print("Available primitives in TCanvas '{0}':".format(
-                    path_to_canvas))
-                for entry in list(canv.GetListOfPrimitives()):
-                    print("Name: '{0}', Type: '{1}'.".format(
-                        entry.GetName(), type(entry)))
-                assert False
-                return entry
-
-            except AssertionError:
-                raise IOError(
-                    "Cannot find any object in file {0} with path {1}".format(
-                        self.tfile, path_to_object))
-
-    def read_graph(self, path_to_graph):
-        """Extract lists of X and Y values from a TGraph.
-
-        :param path_to_graph: Absolute path in the current TFile.
-        :type path_to_graph: str
-
-        :returns: dict -- For a description of the contents,
-            check the documentation of the get_graph_points function.
-
-        """
-        graph = self.retrieve_object(path_to_graph)
-        return get_graph_points(graph)
-
-    def read_hist_2d(self, path_to_hist):
-        """Read in a TH2.
-
-        :param path_to_hist: Absolute path in the current TFile.
-        :type path_to_hist: str
-
-        :returns: dict -- For a description of the contents,
-            check the documentation of the get_hist_2d_points function
-        """
-        hist = self.retrieve_object(path_to_hist)
-        return get_hist_2d_points(hist)
-
-    def read_hist_1d(self, path_to_hist):
-        """Read in a TH1.
-
-        :param path_to_hist: Absolute path in the current TFile.
-        :type path_to_hist: str
-
-        :returns: dict -- For a description of the contents,
-            check the documentation of the get_hist_1d_points function
-        """
-        hist = self.retrieve_object(path_to_hist)
-        return get_hist_1d_points(hist)
-
-    def read_tree(self, path_to_tree, branch_name):
-        """Extract a list of values from a tree branch.
-
-        :param path_to_tree: Absolute path in the current TFile.
-        :type path_to_tree: str
-
-        :param branch_name: Name of branch to read.
-        :type branch_name: str
-
-        :returns: list -- The values saved in the tree branch.
-
-        """
-        tree = self.tfile.Get(path_to_tree)
-
-        values = []
-        for event in tree:
-            values.append(getattr(event, branch_name))
-        return values
-
-    def read_limit_tree(self,
-                        path_to_tree="limit",
-                        branchname_x="mh",
-                        branchname_y="limit"):
-        """
-        Read in CMS combine limit tree.
-
-        :param path_to_tree: Absolute path in the current TFile
-        :type path_to_tree: str
-
-        :param branchname_x: Name of the branch that identifies each of the toys/parameter points.
-        :type branchname_x: str
-
-        :param branchname_y: Name of the branch that contains the limit values.
-        :type branchname_y: str
-
-        :returns: list -- Lists with 1+5 entries per
-            toy/parameter point in the file.
-            The entries correspond to the one number
-            in the x branch and the five numbers in the y branch.
-
-        """
-        # store in multidimensional numpy array
-        tree = self.tfile.Get(path_to_tree)
-        points = int(tree.GetEntries() / 6)
-        values = np.empty((points, 7))
-        limit_values = []
-        actual_index = 0
-        for index, event in enumerate(tree):
-            limit_values.append(getattr(event, branchname_y))
-            # every sixth event starts a new limit value
-            if index % 6 == 5:
-                x_value = getattr(event, branchname_x)
-                values[actual_index] = [x_value] + limit_values
-                limit_values = []
-                actual_index += 1
-        return values
-
-
-def get_hist_2d_points(hist):
-    """
-    Get points from a TH2.
-
-    :param hist: Histogram to extract points from
-    :type hist: TH2D
-
-    :returns: dict -- Lists of x/y/z values saved in dictionary.
-        Corresponding keys are "x"/"y" for the values of the bin center on the
-        respective axis. The bin edges may be found under "x_edges" and "y_edges"
-        as a list of tuples (lower_edge, upper_edge).
-        The bin contents and errors are stored under the "z" key.
-        Bin content errors are stored under the "dz" key as either a list of floats (symmetric case)
-        or a list of down/up tuples (asymmetric).
-        Symmetric errors are returned if the histogram error option
-        TH1::GetBinErrorOption() returns TH1::kNormal.
-    """
-    points = {}
-    for key in ["x", "y", "x_edges", "y_edges", "z", "dz"]:
-        points[key] = []
-
-    symmetric = (hist.GetBinErrorOption() == r.TH1.kNormal)
-    for x_bin in range(1, hist.GetNbinsX() + 1):
-        x_val = hist.GetXaxis().GetBinCenter(x_bin)
-        width_x = hist.GetXaxis().GetBinWidth(x_bin)
-        for y_bin in range(1, hist.GetNbinsY() + 1):
-            y_val = hist.GetYaxis().GetBinCenter(y_bin)
-            z_val = hist.GetBinContent(x_bin, y_bin)
-
-            if symmetric:
-                dz_val = hist.GetBinError(x_bin, y_bin)
-            else:
-                dz_val = (- hist.GetBinErrorLow(x_bin, y_bin),
-                          hist.GetBinErrorUp(x_bin, y_bin))
-
-            width_y = hist.GetXaxis().GetBinWidth(y_bin)
-
-            points["x"].append(x_val)
-            points["x_edges"].append((x_val - width_x / 2, x_val + width_x / 2))
-
-            points["y"].append(y_val)
-            points["y_edges"].append((y_val - width_y / 2, y_val + width_y / 2))
-
-            points["z"].append(z_val)
-            points["dz"].append(dz_val)
-
-    return points
-
-
-
-def get_hist_1d_points(hist):
-    """
-    Get points from a TH1.
-
-    :param hist: Histogram to extract points from
-    :type hist: TH1D
-
-    :returns: dict -- Lists of x/y values saved in dictionary.
-        Corresponding keys are "x" for the value of the bin center.
-        The bin edges may be found under "x_edges" as a list of tuples (lower_edge, upper_edge).
-        The bin contents are stored under the "y" key.
-        Bin content errors are stored under the "dy" key as either a list of floats (symmetric case)
-        or a list of down/up tuples (asymmetric).
-        Symmetric errors are returned if the histogram error option
-        TH1::GetBinErrorOption() returns TH1::kNormal.
-    """
-    points = {}
-    for key in ["x", "y", "x_edges", "dy"]:
-        points[key] = []
-
-    symmetric = (hist.GetBinErrorOption() == r.TH1.kNormal)
-    for x_bin in range(1, hist.GetNbinsX() + 1):
-        x_val = hist.GetXaxis().GetBinCenter(x_bin)
-        width_x = hist.GetXaxis().GetBinWidth(x_bin)
-
-        y_val = hist.GetBinContent(x_bin)
-        if symmetric:
-            dy_val = hist.GetBinError(x_bin)
-        else:
-            dy_val = (-hist.GetBinErrorLow(x_bin), hist.GetBinErrorUp(x_bin))
-
-        points["x"].append(x_val)
-        points["x_edges"].append((x_val - width_x / 2, x_val + width_x / 2))
-
-        points["y"].append(y_val)
-        points["dy"].append(dy_val)
-
-    return points
-def get_graph_points(graph):
-    """
-    Extract lists of X and Y values from a TGraph.
-
-    :param graph: The graph to extract values from.
-    :type graph: TGraph, TGraphErrors, TGraphAsymmErrors
-
-    :returns: dict -- Lists of x, y values saved in dictionary (keys are "x" and "y").
-        If the input graph is a TGraphErrors (TGraphAsymmErrors),
-        the dictionary also contains the errors (keys "dx" and "dy").
-        For symmetric errors, the errors are simply given as a list of values.
-        For asymmetric errors, a list of tuples of (down,up) values is given.
-
-    """
-
-    # Check input
-    if not isinstance(graph, (r.TGraph, r.TGraphErrors, r.TGraphAsymmErrors)):
-        raise TypeError(
-            "Expected to input to be TGraph or similar, instead got '{0}'".
-            format(type(graph)))
-
-    # Extract points
-    points = defaultdict(list)
-
-    for i in range(graph.GetN()):
-        x_val = r.Double()
-        y_val = r.Double()
-        graph.GetPoint(i, x_val, y_val)
-        points["x"].append(float(x_val))
-        points["y"].append(float(y_val))
-        if isinstance(graph, r.TGraphErrors):
-            points["dx"].append(graph.GetErrorX(i))
-            points["dy"].append(graph.GetErrorY(i))
-        elif isinstance(graph, r.TGraphAsymmErrors):
-            points["dx"].append((-graph.GetErrorXlow(i),
-                                 graph.GetErrorXhigh(i)))
-            points["dy"].append((-graph.GetErrorYlow(i),
-                                 graph.GetErrorYhigh(i)))
-
-    return points
